pinax-types
========================

.. image:: https://img.shields.io/travis/pinax/pinax-types.svg
    :target: https://travis-ci.org/pinax/pinax-types

.. image:: https://img.shields.io/coveralls/pinax/pinax-types.svg
    :target: https://coveralls.io/r/pinax/pinax-types

.. image:: https://img.shields.io/pypi/dm/pinax-types.svg
    :target:  https://pypi.python.org/pypi/pinax-types/

.. image:: https://img.shields.io/pypi/v/pinax-types.svg
    :target:  https://pypi.python.org/pypi/pinax-types/

.. image:: https://img.shields.io/badge/license-<license>-blue.svg
    :target:  https://pypi.python.org/pypi/pinax-types/


Welcome to the documentation for pinax-types!


Running the Tests
------------------------------------

::

    $ pip install detox
    $ detox
